Core
====

* `Component`
   - `Mechanism`
   - `Projection`
   - `Port`
   - `Function`

* `Composition`
   - `AutodiffComposition`
   - `CompositionFunctionApproximator`

* `Services`
   - `Visualization`
   - `Log`
   - `Registry`
   - `Preferences`
   - `json`
